Crate goblin_sigscan_pattern

Crate goblin_sigscan_pattern 

Pelite-style pattern parser used by goblin-sigscan.

This crate parses textual signatures into Atom instructions that can be executed by scanner implementations. For scanner-facing onboarding and end-to-end examples, see goblin_sigscan crate docs: https://docs.rs/goblin-sigscan/latest/goblin_sigscan/. The canonical syntax tutorial lives on parse.

Cross references:

  • scanner runtime APIs: goblin_sigscan::Scanner and goblin_sigscan::Matches
  • prepared scanning path: goblin_sigscan::PreparedPattern

Structs

ParsePatError
Pattern parser error.

Enums

Atom
Pattern atoms.
PatError
Pattern parsing error categories.

Functions

parse
Parses a pelite-style signature string into atoms.
save_len
Returns the save array length required by the pattern.

Type Aliases

Pattern
Patterns are a list of Atoms.